# c4counter
This skript takes fasta files containing human HLA regions and returns the number and types of C4 genes (C4A / C4B, HERV / no HERV). In addition, a simple graphical representation in svg format is generated (name: c4.svg)

## Dependencies
minimap2 is used for mapping

## Installation
### pip

`pip install c4counter`

please make sure you have minimap2 installed
### bioconda

`conda install c4counter`

conda will install minimap2 for you
